==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebSummaryOperandDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebSummaryOperandDescription } from "./WebSummaryOperandDescription";
/**
 * @hidden
 */
var WebSummaryOperandDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebSummaryOperandDescriptionMetadata, _super);
    function WebSummaryOperandDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebSummaryOperandDescriptionMetadata.b = function (a) {
        if (WebSummaryOperandDescriptionMetadata.a == null) {
            WebSummaryOperandDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebSummaryOperandDescriptionMetadata.c(WebSummaryOperandDescriptionMetadata.a);
        }
        if (a.j(WebSummaryOperandDescriptionMetadata.a)) {
            return;
        }
        a.y(WebSummaryOperandDescriptionMetadata.a);
    };
    WebSummaryOperandDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:SummaryOperand");
        a.item("__packageNameWC", "String:grids");
    };
    WebSummaryOperandDescriptionMetadata.d = function (a) {
        WebSummaryOperandDescriptionMetadata.b(a);
        a.aa("WebSummaryOperand", function () { return new WebSummaryOperandDescription(); });
        a.z("WebSummaryOperand", WebSummaryOperandDescriptionMetadata.a);
    };
    WebSummaryOperandDescriptionMetadata.$t = markType(WebSummaryOperandDescriptionMetadata, 'WebSummaryOperandDescriptionMetadata');
    WebSummaryOperandDescriptionMetadata.a = null;
    return WebSummaryOperandDescriptionMetadata;
}(Base));
export { WebSummaryOperandDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/WebSummaryOperandDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebSummaryOperandDescription } from "./WebSummaryOperandDescription";
/**
 * @hidden
 */
var WebSummaryOperandDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebSummaryOperandDescriptionMetadata, _super);
    function WebSummaryOperandDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebSummaryOperandDescriptionMetadata.b = function (a) {
        if (WebSummaryOperandDescriptionMetadata.a == null) {
            WebSummaryOperandDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebSummaryOperandDescriptionMetadata.c(WebSummaryOperandDescriptionMetadata.a);
        }
        if (a.k(WebSummaryOperandDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebSummaryOperandDescriptionMetadata.a);
    };
    WebSummaryOperandDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:SummaryOperand");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
    };
    WebSummaryOperandDescriptionMetadata.d = function (a) {
        WebSummaryOperandDescriptionMetadata.b(a);
        a.ac("WebSummaryOperand", function () { return new WebSummaryOperandDescription(); });
        a.ab("WebSummaryOperand", WebSummaryOperandDescriptionMetadata.a);
    };
    WebSummaryOperandDescriptionMetadata.$t = markType(WebSummaryOperandDescriptionMetadata, 'WebSummaryOperandDescriptionMetadata');
    WebSummaryOperandDescriptionMetadata.a = null;
    return WebSummaryOperandDescriptionMetadata;
}(Base));
export { WebSummaryOperandDescriptionMetadata };
